Disclaimer: _This is not an officially supported Google product._

# Optic

Optic is a Python-based UI framework that allows you to rapidly build web demos. Engineers without frontend experience can build web UIs by writing idiomatic Python code.

## Status

Note: Optic is under development.
